@@ -253,7 +253,7 @@ class TaskRequest(Entity):
         git_branch: Optional[UStr],
         task_type: Optional[UStr] = 'cluster',
         task_template: Optional[UStr] = None,
-        task_env: Optional[UStr] = None,
+        task_env: Optional[UDict] = None,
         task_command: Optional[List[UStr]] = ['sleep', '100000'],
         task_arg: Optional[List[UStr]] = None,
         task_working_dir: Optional[UStr] = None,
