@@ -7,9 +7,15 @@ def __fill_class(model_json, model_class):
     fields = model_class.__fields__
     new_json = {}
     for key in model_json:
-        print(key, fields[key].type_)
-        if key in fields and issubclass(fields[key].type_, BaseModel) and model_json[key] is not None:
+        # complex type in list
+        if key in fields and issubclass(fields[key].type_, BaseModel) \
+            and model_json[key] is not None and isinstance(model_json[key], list):
+            new_json[key] = [__fill_class(m, fields[key].type_) for m in model_json[key]]
+
+        elif key in fields and issubclass(fields[key].type_, BaseModel) \
+            and model_json[key] is not None and not isinstance(fields[key], list):
             new_json[key] = __fill_class(model_json[key], fields[key].type_)
+
         elif key in fields:
             new_json[key] = model_json[key]
 
